==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/SnssaiArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Single-network slice selection assistance information (S-NSSAI).
 * @property sd Slice differentiator (SD).
 * @property sst Slice/service type (SST).
 */
public data class SnssaiArgs(
    public val sd: Output<String>? = null,
    public val sst: Output<Int>,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs.builder()
            .sd(sd?.applyValue({ args0 -> args0 }))
            .sst(sst.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SnssaiArgs].
 */
@PulumiTagMarker
public class SnssaiArgsBuilder internal constructor() {
    private var sd: Output<String>? = null

    private var sst: Output<Int>? = null

    /**
     * @param value Slice differentiator (SD).
     */
    @JvmName("ytduotnbqvvrqpsj")
    public suspend fun sd(`value`: Output<String>) {
        this.sd = value
    }

    /**
     * @param value Slice/service type (SST).
     */
    @JvmName("dtpehknrnpdmsgxq")
    public suspend fun sst(`value`: Output<Int>) {
        this.sst = value
    }

    /**
     * @param value Slice differentiator (SD).
     */
    @JvmName("spdsjjjmriwfojgb")
    public suspend fun sd(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sd = mapped
    }

    /**
     * @param value Slice/service type (SST).
     */
    @JvmName("egvbwavtfnvxnqgf")
    public suspend fun sst(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sst = mapped
    }

    internal fun build(): SnssaiArgs = SnssaiArgs(
        sd = sd,
        sst = sst ?: throw PulumiNullFieldException("sst"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/SnssaiArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Single-network slice selection assistance information (S-NSSAI).
 * @property sd Slice differentiator (SD).
 * @property sst Slice/service type (SST).
 */
public data class SnssaiArgs(
    public val sd: Output<String>? = null,
    public val sst: Output<Int>,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.SnssaiArgs.builder()
            .sd(sd?.applyValue({ args0 -> args0 }))
            .sst(sst.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SnssaiArgs].
 */
@PulumiTagMarker
public class SnssaiArgsBuilder internal constructor() {
    private var sd: Output<String>? = null

    private var sst: Output<Int>? = null

    /**
     * @param value Slice differentiator (SD).
     */
    @JvmName("wndqbnmndrotdbfm")
    public suspend fun sd(`value`: Output<String>) {
        this.sd = value
    }

    /**
     * @param value Slice/service type (SST).
     */
    @JvmName("segxhhsjawotknnn")
    public suspend fun sst(`value`: Output<Int>) {
        this.sst = value
    }

    /**
     * @param value Slice differentiator (SD).
     */
    @JvmName("fjmgmvonsmtmdhnr")
    public suspend fun sd(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sd = mapped
    }

    /**
     * @param value Slice/service type (SST).
     */
    @JvmName("glacjblhdvlimbsv")
    public suspend fun sst(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sst = mapped
    }

    internal fun build(): SnssaiArgs = SnssaiArgs(
        sd = sd,
        sst = sst ?: throw PulumiNullFieldException("sst"),
    )
}
